set more off
set logtype text, perm

log using data, replace

use wls57_2004_pub_11_11selected_variables, clear


/*=====================================================*/
/*SELECTION ONLY RESPONDENTS WITH PARTNER AND CHILDREN */
/*=====================================================*/

gen partner=0
replace partner=1 if rc001re==1
drop if partner==0

gen children=0
replace children=rd001kd if rd001kd>=0 & rd001kd<=14

drop if children==0
    
gen female=0
replace female=1 if sexrsp==2

/*==========================================*/
/*      EDUCATION PARENTS                   */
/*==========================================*/

generate opl=edeqyr if edeqyr>=12 & edeqyr<=20
generate oplp=edlsp if edlsp>0 & edlsp<=26

gen efather=opl
gen emother=oplp

replace efather=oplp if female==1
replace emother=opl  if female==1

drop if opl==.
drop if oplp==.

/*===================================*/
/* AGE AND GENDER CHILD              */
/*===================================*/

generate age92=1992-rd014sk
replace age92=. if rd014sk<1952

generate gender=.
replace gender=1 if rd003sk==2
replace gender=0 if rd003sk==1


//keep if child is own birth child

gen typesk=rd004sk
keep if typesk==0

/*======================================================*/
/*   COMPLETED EDUCATION CHILD OBSERVED IN 2004         */
/*======================================================*/

gen e04=gd010sk if gd010sk>0 & gd010sk<=24 & gd011sk==1
replace e04=gd010sk-1 if gd010sk>0 & gd010sk<=24 & gd011sk==2

/*===============================================*/
/*  OBSERVED EDUCATION  CHILD IN 1992            */
/*===============================================*/

gen e92=rd010sk if rd010sk>0 & rd010sk<=24 & rd011sk==1 
replace e92=rd010sk-1 if rd010sk>0 & rd010sk<=24 & rd011sk==2 

 
gen c0=0 
replace c0=1 if age92<=17
replace c0=1 if rd012sk==1 
replace c0=0 if rd011sk==1 & rd012sk==1 & age92>=27
replace c0=0 if rd011sk==2 & rd012sk==1 & age92>=27

// for noncensored observations: replace education by the maximum of 1992 and 2004 
replace e92=e04 if e04>e92 & c0~=1 & e04~=. & e92~=.
replace e04=e92 if e04<e92 & c0~=1 & e92~=. & e04~=.

/*============================================================*/
/* EDUCATION CHILD--EXPECTED VALUES FOR CENSORED OBSERVATIONS*/
/*============================================================*/
gen expedu=edexsk
replace expedu=. if edexsk<=0
replace expedu=. if edexsk>13
recode expedu 1=10 2=12 3=13 4=. 5=14 6=16 7=18 8=20 9=19 10=19 11=19 12=19 13=.  

gen e92br=e92
replace e92br=expedu if c0==1 & e92~=. & expedu~=.
replace e92br=. if c0==1 & expedu==. 
replace e92br=. if c0==1 & e92==.  

/*====================================================================*/
/* KEEP IF (expected) EDUCATION IS OBSERVED IN 1975,1992 AND IN 2004  */
/* KEEP IF CHILD HAS SAME REPORTED BIRTH YEAR IN 92 & 04              */
/*====================================================================*/


keep if e92~=. & e04~=. & expedu~=.

keep if rd014sk-gd014sk==0

label var efather "education father"
label var emother "education mother"
label var age92 "age child in 1992"
label var gender "gender child"
label var expedu "parent's expectations for child's education"
label var e92 "child's education observed in 1992"
label var e04 "child's completed education observed in 2004"
label var e92br "child's education in 1992, replaced by parental expectation for child in school"
label var c0 "1 if observation is censored"
label var female "gender respondent (parent)"
label var brdxdy "birthyear respondent (parent)"

keep female brdxdy efather emother age92 gender e04 e92 c0 expedu e92br iduser

save dataWLScensoring, replace
