set mem 500m
set maxvar 15000
set matsize 1000

set more off
set logtype text, perm

log using results, replace

use dataWLScensoring, clear


/*==============================*/
/* SUMMARY STATISTICS (Table 1) */
/*==============================*/

sum e04 e92 expedu emother efather c0 gender age92


/*===================================*/
/* MAIN RESULTS (column 1-6 Table 2) */
/*===================================*/

/* NO METHOD--education observed in 1992 */

regress e92 emother gender age92
regress e92 efather gender age92
regress e92 emother efather gender age92


/*REPLACEMENT METHOD */

regress e92br emother gender age92
regress e92br efather gender age92 
regress e92br emother  efather gender age92


/*CENSORED REGRESSION MODEL*/

gen e92plug=e92
replace e92plug=. if c0==1

intreg e92 e92plug emother gender age92 
intreg e92 e92plug efather gender age92 
intreg e92 e92plug emother efather gender age92


/*ELIMINATION METHOD */

regress e92 emother gender age92 if age92>=25
regress e92 efather gender age92 if age92>=25
regress e92 emother efather gender age92 if age92>=25


/* COMPLETED SCHOOLING--EDUCATION OBSERVED IN 2004 */

regress e04 emother gender age92 
regress e04 efather gender age92
regress e04 emother efather gender age92


/* COMPLETED SCHOOLING and tests for normality and heteroskedasticity */

regress e04 emother efather gender age92
predict res1 if e(sample), resid
sktest res1

regress e04 emother efather gender age92
estat hettest, iid
estat hettest, iid rhs


/*=================================================*/
/* POOLING DATA SETS TO TEST THE DIFFERENT METHODS */
/*=================================================*/

// ECHILD=E04                  

use dataWLScensoring, clear

keep e04 efather emother age92 gender iduser c0 female
gen eplug=e04
rename e04 echild
gen dummy=0

save edu2004, replace
clear



// ECHILD=E92, no method      

use dataWLScensoring, clear

keep e92 efather emother age92 gender iduser c0 female
gen eplug=.
rename e92 echild
gen dummy=1

save edu1992_nomethod, replace
clear



// ECHILD=E92BR, REPLACEMENT METHOD               

use dataWLScensoring, clear

keep e92br efather emother age92 gender iduser c0 female
gen eplug=.
rename e92br echild
gen dummy=1

save edu1992_replacement, replace
clear



// ECHILD=E92, CENSORED REGRESSION MODEL      

use dataWLScensoring, clear

keep e92 efather emother age92 gender iduser c0 female
gen eplug=e92
replace eplug=. if c0==1
rename e92 echild
gen dummy=1

save edu1992_censmodel, replace

clear


// ECHILD=E92 IF AGE92>=25, ELIMINATION METHOD     

use dataWLScensoring, clear

keep e92 efather emother age92 gender iduser c0 female
gen eplug=.
keep if age92>=25
rename e92 echild
gen dummy=1

save edu1992_elimination, replace
clear



/*==========================================*/
/*      TESTS (column 7,8 and 9 Table 2)    */
/*==========================================*/

// TEST NO METHOD

use edu2004, clear
append using edu1992_nomethod

generate emother04=emother*dummy
generate efather04=efather*dummy
generate gender04=gender*dummy
generate age9204=age92*dummy

regress echild emother emother04 dummy gender gender04 age92 age9204, cluster(iduser)

regress echild efather efather04 dummy gender gender04 age92 age9204, cluster(iduser)

regress echild emother efather emother04 efather04 dummy gender gender04 age92 age9204, cluster(iduser)

clear



// TEST REPLACEMENT METHOD 

use edu2004, clear
append using edu1992_replacement

generate emother04=emother*dummy
generate efather04=efather*dummy
generate gender04=gender*dummy
generate age9204=age92*dummy

regress echild emother emother04 dummy gender gender04 age92 age9204, cluster(iduser)

regress echild efather efather04 dummy gender gender04 age92 age9204, cluster(iduser)

regress echild emother efather emother04 efather04 dummy gender gender04 age92 age9204, cluster(iduser)

clear


// TEST CENSORED REGRESSION MODEL        

use edu2004, clear
append using edu1992_censmodel

generate emother04=emother*dummy
generate efather04=efather*dummy
generate gender04=gender*dummy
generate age9204=age92*dummy

intreg echild eplug emother emother04 dummy gender gender04 age92 age9204, cluster(iduser)

intreg echild eplug efather efather04 dummy gender gender04 age92 age9204, cluster(iduser)

intreg echild eplug emother efather emother04 efather04 dummy gender gender04 age92 age9204, cluster(iduser)

clear



// TEST ELIMINATION METHOD 

use edu2004, clear
append using edu1992_elimination

generate emother04=emother*dummy
generate efather04=efather*dummy
generate gender04=gender*dummy
generate age9204=age92*dummy

regress echild emother emother04 dummy gender gender04 age92 age9204, cluster(iduser)

regress echild efather efather04 dummy gender gender04 age92 age9204, cluster(iduser)

regress echild emother efather emother04 efather04 dummy gender gender04 age92 age9204, cluster(iduser)
clear



/*====================*/
/*ROBUSTNESS CHECKS   */
/*====================*/

use dataWLScensoring, clear

gen diff=expedu-e04 if e04~=. & expedu~=.

gen diffabsoluut=abs(diff)

sum diffabsoluut diff

regress diff emother age92 gender 
regress diff efather age92 gender 
regress diffabsoluut emother age92 gender 
regress diffabsoluut efather age92 gender 

/*====================================================*/
/* HOW DO THE METHODS PERFORM WHEN NUMBER OF CENSORED */
/* OBSERVATIONS IS INCREASED BY LOOKING BACK IN TIME  */
/*====================================================*/

gen d0=0
replace d0=1 if c0==1

forvalues i = 1/20  {
				gen d`i'=0
				replace d`i'=1 if c0==1
				replace d`i'=1 if e92>(age92-6-`i') & d`i'==0
                      }

gen d100=0
replace d100=1 

save data_d, replace



/*=======================================================================*/
/* 	INCREASING CENSORING PERCENTAGES; ALL METHODS (TABLE 3)	       */
/*=======================================================================*/

use data_d, clear

foreach i of numlist 4 6 8 10 11 12 {
				tab d`i'
						}

/*REPLACEMENT METHOD*/

foreach i of numlist 0 4 6 8 10 11 12 100   {   
				use data_d, clear
				gen ed`i'=.
				replace ed`i'=e92 
				replace ed`i'=expedu if d`i'==1 & e92~=. & expedu~=.	
				replace ed`i'=. if d`i'==1 & expedu==. 
				replace ed`i'=. if d`i'==1 & ed`i'==.
				
				keep if ed`i'~=. & e04~=.	
				sum ed`i' e04 d`i' c0				
				
				regress ed`i' emother efather gender age92
				est store eqbr`i'

				regress e04 emother efather gender age92
				est store eq04`i'

				suest eqbr`i' eq04`i'
				
				lincom [eqbr`i'_mean]emother-[eq04`i'_mean]emother
				lincom [eqbr`i'_mean]efather-[eq04`i'_mean]efather

				clear
			    }


/* CENSORED REGRESSION MODEL*/

foreach i of numlist 0 4 6 8 10 11 12    {   
				use data_d, clear
				gen ed`i'=.
				replace ed`i'=e92 
				replace ed`i'=age92-6-`i' if d`i'==1 & e92~=. & e92>age92-6-`i'			
				keep if ed`i'~=. & e04~=.
				
				sum ed`i' e04 d`i' c0				

				gen eplug=ed`i'
				replace eplug=. if d`i'==1
				
				intreg ed`i' eplug emother efather gender age92 if age92-`i'>6, score( a`i' b`i' )
				est store eqplug`i'

				regress e04 emother efather gender age92
				est store eq04b`i'

				suest eqplug`i' eq04b`i'
				
				lincom [eqplug`i'_model]emother-[eq04b`i'_mean]emother
				lincom [eqplug`i'_model]efather-[eq04b`i'_mean]efather

				clear
			    }


/* ELIMINATION METHOD*/

foreach i of numlist 0 4 6 8 10  {   
				use data_d, clear
				gen ed`i'=.
				replace ed`i'=e92 
				replace ed`i'=age92-6-`i' if d`i'==1 & e92~=. & e92>age92-6-`i'
				
				keep if ed`i'~=. & e04~=.
				
				sum ed`i' e04 d`i' c0				

				regress ed`i' emother efather gender age92 if age92-`i'>=25
				est store eqblack`i'

				regress e04 emother efather gender age92
				est store eq04a`i'

				suest eqblack`i' eq04a`i'
				
				lincom [eqblack`i'_mean]emother-[eq04a`i'_mean]emother
				lincom [eqblack`i'_mean]efather-[eq04a`i'_mean]efather

				clear

				}


/*==============================*/
/*        TABLE 4               */
/*==============================*/


//WLS

use dataWLScensoring, clear

keep if expedu~=. & efather~=. & emother~=. & female==1 

gen agechild=age92-17

gen agemother=75-brdxdy if brdxdy<45
sum expedu emother efather agemother agechild

regress expedu emother agemother
regress expedu efather agemother
regress expedu emother efather agemother


//PSID

clear

use psid1976_selected_variables, clear

gen emother=V4755 if V4743>0 & V4755<99

gen efather=V4684 if V4684<99

gen expedumost= V4838

/* 0=.                                           */
/* 1=0-5 grades                                  */
/* 2=6-8 grades                                  */
/* 3=some high school                            */
/* 4=high school                                 */
/* 5=12 grades plus nonacademic training         */
/* 6=College but no degree                       */
/* 7=College BA and no advanced degree           */
/* 8=College and advanced or professional degree */
/* 9= NA or DK                                   */

recode expedumost 0=. 1=. 2=. 3=10 4=12 5=13 6=14 7=16 8=19 9=.

gen expeduleast= V4839
recode expeduleast 0=. 1=. 2=. 3=10 4=12 5=13 6=14 7=16 8=19 9=.

egen expedu=rowmean( expedumost expeduleast)

keep if expedu~=. & efather~=. & emother~=.

gen agemother=V4743

sum  expedu efather emother agemother

regress expedu emother agemother
regress expedu efather agemother
regress expedu emother efather agemother




//NLSY 

clear

use nlsy_selected_variables, clear

gen child_id= C0000100
gen motherid= C0000200

gen emother1996= C0061122 if  C0061122>0 & C0061122<=20
gen epartner1996=C0128028 if C0128028>0 & C0128028<=20
gen espouse1996=C0128025 if C0128025>0 & C0128025<=20

gen efather1996=espouse1996
replace efather1996=epartner1996 if espouse1996==.

gen expedu1996=C1644200  if  C1644200>0 & C1644200<6

/* 1=leave high school before graduation */
/* 2=graduate from high school           */
/* 3=get some college or other training  */
/* 4=graduate from college               */
/* 5=take further training after college */ 

recode expedu1996 1=10 2=12 3=14 4=16 5=19 

keep if expedu1996~=. & efather1996~=. & emother1996~=.

gen agemother1996= C0038235 if  C0038235>=0
gen agechild1996 =C0004743/12 if C0004743>=0
sum expedu1996 efather1996 emother1996 agemother1996 agechild1996

regress  expedu1996 emother1996 agemother1996, cluster(motherid)
regress  expedu1996 efather1996 agemother1996, cluster(motherid)
regress  expedu1996 emother1996 efather1996 agemother1996, cluster(motherid)





